/// A set of priority levels for tasks.
#[derive(Clone, Copy, PartialEq, PartialOrd, Eq, Ord)]
pub enum Priority
{
   /// The lowest priority level. This is for
   /// tasks that you don't care when they finish.
   Lowest,

   /// A low priority task. This is for tasks that are not
   /// as important as normal tasks.
   Low,

   /// A normal priority task. This is for most tasks to use.
   Normal,

   /// A high priority task. This is for tasks that need to make
   /// sure they are scheduled to be done prior to most other tasks.
   High,

   /// The highest priority task. This is for tasks that
   /// must be run right away.
   Highest
}



impl Priority
{
   /// Get a str representation of this variant.
   pub fn to_str(&self) -> &'static str
   {
      match *self
      {
         Priority::Lowest =>
         {
            "Lowest"
         }

         Priority::Low =>
         {
            "Low"
         }

         Priority::Normal =>
         {
            "Normal"
         }

         Priority::High =>
         {
            "High"
         }

         Priority::Highest =>
         {
            "Highest"
         }
      }
   }

   /// Get a String representation of this variant.
   pub fn to_string(&self) -> String
   {
      String::from(self.to_str())
   }
}

impl ::std::fmt::Debug for Priority
{
   fn fmt(&self, f: &mut ::std::fmt::Formatter) -> ::std::fmt::Result
   {
      write!(f, "{}", self.to_str())
   }
}

impl ::std::fmt::Display for Priority
{
   fn fmt(&self, f: &mut ::std::fmt::Formatter) -> ::std::fmt::Result
   {
      write!(f, "{}", self.to_str())
   }
}
