use std::cmp::Ordering;

use ::task::Task;
use ::task_state::TaskState;



/// A trait
pub trait TaskStateMachine: Task
{
   ///
   fn get_state(&self) -> TaskState;
}



impl PartialEq for TaskStateMachine
{
   fn eq(&self, other: &Self) -> bool
   {
      // Compare them first by priority, then by name.
      match self.get_priority().cmp(&other.get_priority())
      {
         Ordering::Equal =>
         {
            self.get_name().to_string().eq(&other.get_name().to_string())
         }

         _ =>
         {
            false
         }
      }
   }
}

impl Eq for TaskStateMachine
{
}

impl PartialOrd for TaskStateMachine
{
   fn partial_cmp(&self, other: &Self) -> Option<Ordering>
   {
      Some(self.cmp(other))
   }
}

impl Ord for TaskStateMachine
{
   fn cmp(&self, other: &Self) -> Ordering
   {
      // Compare them first by priority, then by name.
      match self.get_priority().cmp(&other.get_priority())
      {
         Ordering::Less =>
         {
            Ordering::Less
         }

         Ordering::Equal =>
         {
            match self.get_state().cmp(&other.get_state())
            {
               Ordering::Less =>
               {
                  Ordering::Less
               }

               Ordering::Equal =>
               {
                  self.get_name().to_string().cmp(
                     &other.get_name().to_string())
               }

               Ordering::Greater =>
               {
                  Ordering::Greater
               }
            }
         }

         Ordering::Greater =>
         {
            Ordering::Greater
         }
      }
   }
}
